function v=graphicsRunHetero(nc,n,a,t,cu,du,nt,cp,d,dh,pr,contactType,decisionType,ExList,IniDecList)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns model trajectory matrix + plot; uniform authority (cue   %
% values); uniform intial decisions; AGENT BEHAVIOR DISTRIBUTION   %
% FIXED IN FUNCTION                                                %
%                                                                  %
% Input: nc=number of cycles; n=number of nodes; a=number of       % 
% alternatives; t=max number of choices of contact minimalists /   %
% information capacity; cu=indicator contact type uniform (1       %
% uniform, 0 fixed distribution); du=indicator decisons type       %
% uniform (1 uniform, 0 fixed distribution), FIXED DISTRIBUTION    %
% DECLARED IN FUNCTION!; nt=network type (1 complete, 2 poisson,   %
% 3 scale free, 4 small world); cp=poisson/connection probability; %
% d=scale free/minDregree; dh=small world/number of connections on %
% each side; pr=smallworld/probability of rewiring; contactType := %
% 1-minimalistTallied, 2-all,3-TTB, 4-Better Equal (cu must be set %
% to 1); decisionType := 1-conditionalMinimalist, 2-TTB, 3-UWM,    %
% 4-WAM (du must be set to 1); ExList := List of expertizes, will  %
% be shuffled randomly; IniDecList := List of initial decisions,   %
% will be shuffled randomly                                        %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), August 30st 2006     %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


tic;                        %start timer

cycviz=nc;                  %all cycles are displayed in trajectory of decision proportions
   
%structure of agent population 
                                                        %------ContactTypes: 1-minimalistTallied, 2-all,3-TTB, 4-BE 
    
    if cu==1
        ContactType=uniformClassesContact(n,contactType);                   %uniform vector of agents contact behavior
    elseif cu==0
        ContactType=randomClassesContact(n,0.25,0.25,0.25,0.25)   %random vector of agents contact behavior (number as ordered) 
    end
                                                        %------DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM
    
    if du==1
        Type=uniformClasses(n,decisionType);                                 %uniform vector of agents decision behavior
    elseif du==0
        Type=randomClasses(n,0.25,0.25,0.25,0.25);                %random vector of agents decision behavior (number as ordered)
    end

%determine agent type indicators:-----

    contactIndiMINI=1;                                  %contact Minimalist Tallied
    contactIndiALL=2;                                   %contact all
    contactIndiTTB=3;                                   %contact the best
    contactIndiBE=4;                                    %contact better equal
    contactIndiTP=5;                                    %contact take proportional
    
    indiMINI=1;                                         %decision conditional minimalist
    indiTTB=2;                                          %decision TTB
    indiUWM=3;                                          %decision UWM
    indiWAM=4;                                          %decision WAM
    indiPROP=5;                                         %decision take proportional
    

%build network-------------------------

    if nt==1
        A=buildComplete(n);                             %complete graph
    elseif nt==2
        A=buildPoisson(n,cp);                           %poisson graph
    elseif nt==3
        A=prefAtt(n,d);                                 %scale free graph
    elseif nt==4
        A=smallWorld(n,dh,pr);                          %small world graph
    end
    
%value graph-------------------------------------------

    global Weights;    

    %Weights=valueObjectiveUniform(A);                   %assign uniform competencies
    
    RandomizedList=drawListWithoutReplacement(n,ExList); %Expertize distribution is assigned randomly to agents
    Weights=valueObjectiveList(A,RandomizedList);        %adjaceny matrix is valued according to shuffled list of expertizes
    
%build initial decisions----------------

    Decisions=drawListWithoutReplacement(n,IniDecList);
    DInit=Decisions;

%initialize output trajectory--------------------------

    TRA=DInit;                                          %initial decisions
 
%simulate----------------------------------------------
%simulate----------------------------------------------
%simulate----------------------------------------------
    
    cyc=1;
    for cyc=1:nc                                        %SIMULATE FOR nc CYCLES
        
        %cyc    
    
    
%select contacts---------------------------------------

        Contacts=zeros(n,n);                            %In Principle "Contacts" is unneccessary IV, no influence on 
                                                        %contact decision; what happens: an empty matrix is sucessively filled
        
        Contacts=contactMinimalistTallied(ContactType,contactIndiMINI,Weights,Contacts,t); %during each function call (of e.g. "minimalist..." it is checked in the called function, wether decision type applies 
        Contacts=contactAll(ContactType,contactIndiALL,Weights,Contacts);
        Contacts=contactTakeTheBest(ContactType,contactIndiTTB,Weights,Contacts);
        Contacts=contactBetterEqual(ContactType,contactIndiBE,Weights,Contacts); 
        Contacts=contactTakeProportional(ContactType,contactIndiTP,Weights,Contacts);
        
%choose from socially cued alternatives----------------

        D1=zeros(n,1);                                  %A distinct decision vector for each agent type
        D2=zeros(n,1);
        D3=zeros(n,1);
        D4=zeros(n,1);
        D5=zeros(n,1);                                  %NEWLY INTRODUCED FOR "PROPORTIONAL_BEST"
        
        
        D1=ConditionalMinimalistH(a,Type,indiMINI,Contacts,Decisions);      %decisions for heterogeneous environments "H"
        D2=takeTheBestH(Type,indiTTB,Contacts,Decisions);
        D3=UWMrH(Type,indiUWM,Contacts,Decisions,a);  
        D4=WAMrH(Type,indiWAM,Contacts,Decisions,a); 
        D5=takeProportional(a,Type,indiPROP,Contacts,Decisions);
            
        D=addVectors(n,D1,D2,D3,D4,D5);                    %adding means spelling, since all but one matrices are zero
        
        Decisions=D;                                    %update the decision vector
        
%track results-----------------------------------------
                                                        
        TRA=[TRA, Decisions];                           %build trajectory
                                                        %concatenate past and present
                                                        %[n,1]-matrices are
                                                        %concatenated cyc
                                                        %times;
    end

%end simulate------------------------------------------
%end simulate------------------------------------------
%end simulate------------------------------------------ 

%plot results------------------------------------------    
    
    Taxis=1:1:nc+1;                                     %build a time axis
    PD=computeProportion(TRA,n,a,nc);                   %build matrix of decision proportions over time
    
    subplot(2,1,1); plot(Taxis,TRA, '--square');        %plot results; alternative styles: '-',':','o','*'
    xlabel('cycle')
    ylabel('decision indicator')
    title('Trajectories of Agents Decisions')
    
    
    subplot(2,1,2); bar(PD(:,1:cycviz+1).');             %plot bar graph of decision proportions
    xlabel('cycle')
    ylabel('proportion')
    title('Decision Distribuition over Time')
    
%end run-----------------------------------------------

    NoCycles=cyc                                        %Return total number of cycles
    %toc;                                                %Return elapsed time
    
    v=TRA