function v=proportionOpinionChange(Trajectory,Weights,experts)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns proportion of opinion change; either for all agents or   %
% for only for experts (above average expertise); differences      %
% between intial- and final decision are examined                  %
%                                                                  %
% Input: Trajectory := Model Trajectory, Weights := weight matrix  %
% (global variable), Experts := 1=Proportion for Experts, 0=       %
% proportions for all agents                                       %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), August 24th 2006     %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nCycles=length(Trajectory(1,:));     %number of cycles
nAgents=length(Trajectory(:,1));     %number of agents
Expertize=zeros(nAgents,1);          %vector of agents expertizes
IExpert=zeros(nAgents,1);            %indicator of expert status (above average expertize)
nExperts=0;                          %number of experts
IChange=zeros(nAgents,1);            %indicator of decision change
pChange=0;                           %proportion of opinion change


%---------collect complete expertize-vector from self weights

i=1;

for i=1:nAgents
    Expertize(i,1)=Weights(i,i);
    i=i+1;
end

%---------determine mean expertize and count number of experts

mExpertize=mean(Expertize);

i=1;
for i=1:nAgents
    if Expertize(i,1) > mExpertize                                          %set expertize indicators
        IExpert(i,1)=1;
    end
    i=i+1;
end

nExperts=sum(IExpert(:,1));                                                 %count expertize indicators

%--------determine proportion of decision changes

if experts == 0             %all agents
    
    i=1;
    for i=1:nAgents
        if Trajectory(i,1) ~= Trajectory(i,nCycles)                         %if there is change -> set indicator
            IChange(i,1)=1;
        end
        i=i+1;
    end
    pChange=sum(IChange(:,1))/nAgents;                                      %compute proportions
end

if experts == 1             %experts

    i=1;
    for i=1:nAgents
        if (IExpert(i,1) == 1)&(Trajectory(i,1) ~= Trajectory(i,nCycles))   %if there is change & expert-status -> set indicator
            IChange(i,1)=1;
        end
        i=i+1;
    end
    pChange=sum(IChange(:,1))/nExperts;                                      %compute proportions, respective to number of experts
end
    
v=pChange;
        



        