%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% COMPUTES "graphicsRunMainAppl", which simulates LAZEGAs lawyers %
% which returns graphics of trajectory                             %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), October 26th 2006    %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
tic
load LawyerInfluenceData.mat

%----REPETITIONS
rep=1;

%----PARAMETERS
nUpdates=100;
nAgents=36;
nAlternatives=2;
tallying=3;
contactUniform=1;
decisionUniform=1;
contactType=2;                                         %ContactTypes: 1-minimalistTallied, 2-all, 3-TTB, 4-BE, 5-take proportional
decisionType=1;                                        %DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM, 5-take proportional

%IniDecList=[0;0;1;1;0;0;0;0;0;0;0;1;1;1;0;0;1;1;0;1;0;1;0;1;0;1;1;1;1;0;1;0;0;1;0;0];   %Empirical List of Initial Decisions
IniDecList=workflowOpinionRecoded;

%empirical, weighted adjacency matrix

AMatrix=influencingRates;

%----auxiliary parameters

global Weights;                                  %declaration "global" in main- and subfunctions makes "Weights" globally availiable;
                                                 %necessary for determination of expertize
                                        
all=0;                                           %parameters of proportionOpinionChange
experts=1;

allExperts=0;                                    %parameters of determineCompromiseQuality
bestExpert=1;

%----INSTRUCTIONS

UnanimityCycleVector=zeros(1,rep);               %vector of n(cycle) in which unanimity is reached
unAnimityVector=zeros(1,rep);                    %vector indicators (1/0) wether 1animity is reached        
twoAnimityVector=zeros(1,rep);                   %vector indicators (1/0) wether 2animity is reached
threeAnimityVector=zeros(1,rep);                 %vector indicators (1/0) wether 3animity is reached
proportionChangesVector=zeros(1,rep);            %vector of proportions of decision changes (all)
proportionExpertChangesVector=zeros(1,rep);      %vector of proportions of decision changes (experts)
CompromiseQualityVector=zeros(1,rep);            %vector of indicators (1/2, 0) wether unianimous decison differs from expert initial decision
CompromiseQualityVectorAllExperts=zeros(1,rep);  %vector of indicators (1/2, 0) wether unianimous decison differs from experts mode initial decision


k=1;
for k=1:rep                         %REPEAT SIMULATIONS AND COMPUTE AGGREGATE RESULTS
     
    %----compute trajectory
    
    Trajectory=graphicsRunAppl(nUpdates,nAgents,nAlternatives,tallying,contactUniform,decisionUniform,contactType,decisionType,IniDecList,AMatrix);
    
    EqilibriumAtCycle=equilibriumCycle(Trajectory)       %output equilibrium cycle
    
    %----increment loop
    
    k=k+1;
    
end                                 %END REPEAT SIMULATIONS

NoRep=rep                                 %output n repetitions
toc                                 %output time

%-----------plot ajacency matrix / trajectory is plotted in "graphicsRunHetero-------------------

figure
subplot(2,1,1); spy(Weights);             %plot binary adjacency matrix
    xlabel('Receiving Agent')
    ylabel('Exerting Agent')
    title('Adjacency Pattern')

subplot(2,1,2); stem3(Weights);             %plot weighted adjacency matrix
    xlabel('Receiving Agent')
    ylabel('Exerting Agent')
    zlabel('Weight')
    title('Weighted Ajacency Pattern')

    
    
