%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Application on empirical data (simulates LAZEGAs lawyers)       %
% COMPUTES AGGREGATED RESULTS OVER "plainRunAppl"                  %
% which returns model trajectory matrix; uniform intial decisions; %
%                                                                  %
% Data is taken from Lazegas Lawyers: inverted partners listening  %
% network, weights taken from hourly rates of partners, initial    %
% decisions concern regulation of workflow (0 no / 1 yes)          %
% Author: Gero Schwenk (Gero.Schwenk@web.de), October 26th 2006    %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
tic

load LawyerInfluenceData.mat

%----REPETITIONS
rep=1;

%----PARAMETERS
nUpdates=50;
nAgents=36;
nAlternatives=2;
tallying=3;
contactUniform=1;
decisionUniform=1;
contactType=2;                                          %ContactTypes: 1-minimalistTallied, 2-all, 3-TTB, 4-BE, 5-take proportional
decisionType=3;                                        %DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM, 5-take proportional

%IniDecList=[0;0;1;1;0;0;0;0;0;0;0;1;1;1;0;0;1;1;0;1;0;1;0;1;0;1;1;1;1;0;1;0;0;1;0;0];   %Empirical List of Initial Decisions
IniDecList=workflowOpinionRecoded;

%empirical, weighted adjacency matrix

AMatrix=influencingRates;


%----auxiliary parameters

global Weights;                                  %declaration "global" in main- and subfunctions makes "Weights" globally availiable;
                                                 %necessary for determination of expertize
                                        
all=0;                                           %parameters of proportionOpinionChange
experts=1;

allExperts=0;                                    %parameters of determineCompromiseQuality
bestExpert=1;

%----INSTRUCTIONS

UnanimityCycleVector=zeros(1,rep);               %vector of n(cycle) in which unanimity is reached
unAnimityVector=zeros(1,rep);                    %vector indicators (1/0) wether 1animity is reached        
twoAnimityVector=zeros(1,rep);                   %vector indicators (1/0) wether 2animity is reached
threeAnimityVector=zeros(1,rep);                 %vector indicators (1/0) wether 3animity is reached
proportionChangesVector=zeros(1,rep);            %vector of proportions of decision changes (all)
proportionExpertChangesVector=zeros(1,rep);      %vector of proportions of decision changes (experts)
CompromiseQualityVector=zeros(1,rep);            %vector of indicators (1/2, 0) wether unianimous decison differs from expert initial decision
CompromiseQualityVectorAllExperts=zeros(1,rep);  %vector of indicators (1/2, 0) wether unianimous decison differs from experts mode initial decision
finalDistributionsMatrix=zeros(nAlternatives,rep);     %matrix of final frequencies of alternatives for each repetition


k=1;
for k=1:rep                         %REPEAT SIMULATIONS AND COMPUTE AGGREGATE RESULTS
     
    %----compute trajectory
    
    %Trajectory=plainRunAppl(nUpdates,nAgents,nAlternatives,tallying,contactUniform,decisionUniform,networkType,connectionProbPoisson,minDegreePref,halfDimensionSmallWorld,probRewireSmallWorld,contactType,decisionType,ExList,IniDecList);                  
    Trajectory=plainRunAppl(nUpdates,nAgents,nAlternatives,tallying,contactUniform,decisionUniform,contactType,decisionType,IniDecList,AMatrix);
    %Trajectory
        
    %----collect some data
    
    UnanimityCycleVector(1,k)=cycleUnanimity(Trajectory);                   %count cycle in which unanimity is reached
    
    unAnimityVector(1,k)=determineUnAnimity(UnanimityCycleVector(1,k));     %build indicator vector of 1-animity
    twoAnimityVector(1,k)=determineTwoAnimity(Trajectory);                  %build indicator vector of 2-animity    
    threeAnimityVector(1,k)=determineThreeAnimity(Trajectory);              %build indicator vector of 3-animity
    
    proportionChangesVector(1,k)=proportionOpinionChange(Trajectory,Weights,all);   %build vector of decision change proportions
    proportionExpertChangesVector(1,k)=proportionOpinionChange(Trajectory,Weights,experts); % "" for experts
    
    CompromiseQualityVector(1,k)=determineCompromiseQuality(Trajectory,Weights,UnanimityCycleVector(1,k),bestExpert);            %build vector of group decision quality (does best expert change decision?)
    CompromiseQualityVectorAllExperts(1,k)=determineCompromiseQuality(Trajectory,Weights,UnanimityCycleVector(1,k),allExperts);  %build vector of group decision quality (is group decision the mode expert decision?) 
    
    
    finalDistributionsMatrix(:,k)=finalDistributions(Trajectory,nAlternatives,nUpdates);
    %----increment loop
    
    k=k+1;
    
end                                 %END REPEAT SIMULATIONS

rep                                 %output n repetitions
time=toc                            %output time
   
    
                                    %CLEAN VECTORS FROM NON-UNANIMITY
    
%UnanimityCycleVector
ClUnanimityCycleVector=cleanUnAnimityCycleVector(UnanimityCycleVector);                             %clean cycle-vector from zeros (repetitions without unanimity)
ClCompromiseQualityVector=cleanUnAnimityCycleVector(CompromiseQualityVector);                       %clean quality-vector from zeros (repetitions without unanimity)
ClCompromiseQualityVectorAllExperts=cleanUnAnimityCycleVector(CompromiseQualityVectorAllExperts);   %clean quality-vector from zeros (repetitions without unanimity)

                                    %ANALYZE DATA
        

pUni=proportionKAnimity(unAnimityVector);                                   %buid distribution of k-animity
pTwo=proportionKAnimity(twoAnimityVector);
pTri=proportionKAnimity(threeAnimityVector);

KAnimityDistribution = [pUni pTwo pTri]

meanAggrementCycle=mean(ClUnanimityCycleVector)                             %determine mean unanimity cycle
stdDevAggrementCycle=std(ClUnanimityCycleVector)

meanPropChange=mean(proportionChangesVector)                                %determine mean change rate of agents (experts)
stdDevPropChange=std(proportionChangesVector)

meanPropExpChange=mean(proportionExpertChangesVector)
stdDevPropExpChange=std(proportionExpertChangesVector)

pBestExpertQuality=proportionQualityDecisions(ClCompromiseQualityVector)   %determine qualitiy of group decision, if unanimous

pAllExpertQuality=proportionQualityDecisions(ClCompromiseQualityVectorAllExperts)

meanFinalDistrib1=mean(finalDistributionsMatrix(1,:))                       %determine mean final decision ddistribution of runs
meanFinalDistrib2=mean(finalDistributionsMatrix(2,:))
%meanFinalDistrib3=mean(finalDistributionsMatrix(3,:))

stdFinalDistrib1=std(finalDistributionsMatrix(1,:))                         %determine std.dev. oof means
stdFinalDistrib2=std(finalDistributionsMatrix(2,:))
%stdFinalDistrib3=std(finalDistributionsMatrix(3,:))

JointResults=[pUni, pTwo, pTri, meanAggrementCycle, stdDevAggrementCycle, meanPropChange, stdDevPropChange, meanPropExpChange, stdDevPropExpChange, pBestExpertQuality, pAllExpertQuality, meanFinalDistrib1, meanFinalDistrib2, stdFinalDistrib1, stdFinalDistrib2];

                                    %SAVE RESULTS;
                                    
save Exp2 JointResults;                     %SaveJoint Results (*.mat, *.dat)
dlmwrite('Exp2.csv', JointResults, ',');

time
    