function v=UWM(Type,indicator,Contacts,Decisions,a)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns vector of agents decisions according to 'linear unit     %
% weight model'; if there is no clear optimum UWM-decision, the    %
% old decision is maintained                                       %
%                                                                  %
% Input: type := vector of agent type with regard to used          %
% heuristic; indicator := labeling number of 'take the best' agent %
% type, Contacts := Matrix of contacts influence weights (cue      %
% values); Decisions := Vector of Decisions; a := number of        %
% alternatives                                                     %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), July 14th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



n=length(Type(:,1));
D=Decisions;
ContactsIndex=zeros(n,n);                   %0-1 contact indicator
IndivUWResult=zeros(n,a);                   %results of UW-counts for all agents

%---------------Build zero-one indicator matrix of contacts--------

i=1;
j=1;

for i=1:n
    for j=1:n
        if Contacts(i,j) ~= 0
            ContactIndex(i,j)=1;
        end
        j=j+1;
    end
    i=i+1;
end

%--------Count Propagating Neighbours over the 'a' alternatives-------

i=1;
j=1;
k=1;

for k=1:a
    i=1;
    for i=1:n
        j=1;
        for j=1:n
            if (Decisions(j,1)==k)&(ContactIndex(j,i)==1)
                IndivUWResult(i,k)=IndivUWResult(i,k)+1;
            end
            j=j+1;
        end
        i=i+1;
    end
    k=k+1;
end

%-----------Choose the alternative with maximum unit weight-------

%ContactIndex
%IndivUWResult

[SD,IX] = sort(IndivUWResult,2);            %Sort (ascending) Individual unit weight results over rows , 
                                            %return sorted matrix and indices

                                        
i=1;
for i=1:n
    if Type(i,1) == indicator               %if agent uses 'linear unit weight'
        if SD(i,a)==SD(i,a-1)               %if there is a tie regarding the (UWM-)best (a-th) option
            D(i,1)=Decisions(i,1);          %don't change decision 
        else                                %else, i.e. if there is a clear winning option,
            D(i,1)=IX(i,a);                 %choose it 
        end
    end
    i=i+1;
end
                                        
                                        
v=D;            