function v=UWMrH(Type,indicator,Contacts,Decisions,a)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns vector of agents decisions according to 'linear unit     %
% weight model'; if there is no clear optimum UWM-decision, the    %
% new decision is selected at random from the concurring optima    %
% decisions of other agent types are set to zero                   %
%                                                                  %                                                                  %
% Input: type := vector of agent type with regard to used          %
% heuristic; indicator := labeling number of 'take the best' agent %
% type, Contacts := Matrix of contacts influence weights (cue      %
% values); Decisions := Vector of Decisions; a := number of        %
% alternatives                                                     %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), July 17th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



n=length(Type(:,1));
D=Decisions;
ContactsIndex=zeros(n,n);                   %0-1 contact indicator
IndivUWResult=zeros(n,a);                   %results of UW-counts for all agents

%---------------Build zero-one indicator matrix of contacts--------

i=1;
j=1;

for i=1:n
    for j=1:n
        if Contacts(i,j) ~= 0
            ContactsIndex(i,j)=1;
        end
        j=j+1;
    end
    i=i+1;
end


%--------Count Propagating Neighbours over the 'a' alternatives-------

i=1;
j=1;
k=1;

for k=1:a
    i=1;
    for i=1:n
        j=1;
        for j=1:n
            if (Decisions(j,1)==k)&(ContactsIndex(j,i)==1)
                IndivUWResult(i,k)=IndivUWResult(i,k)+1;
            end
            j=j+1;
        end
        i=i+1;
    end
    k=k+1;
end

%-----------Choose the alternative with maximum unit weight-------

%ContactIndex
%IndivUWResult

[SD,IX] = sort(IndivUWResult,2);            %Sort (ascending) Individual unit weight results over rows , 
                                            %return sorted matrix and indices

                                        
i=1;
c1=a-1;                                     %counter of while loop (upper bound)
c2=1;                                       %counter of ties

for i=1:n
    c1=a-1;
    c2=1;
    if Type(i,1) == indicator               %if agent uses 'linear unit weight'
        while (SD(i,c1)==SD(i,a))&(c1>1)    %while there is a tie between SD(a) and another SD & (there is an option left to count)
            c2=c2+1;                        %count how many equals there are
            c1=c1-1;                        %decrement loop index
        end
        if c2>1;                            %if there is a tie counted (regarding the (UWM-)best (a-th) option)
            r=ceil(rand(1)*(c2));           %compute a random number between 1 and number of equals
            D(i,1)=IX(i,(a+1)-r);           %and choose from ties randomly (i.e.choose randomly from the upper c2's)
        else                                %else, i.e. if there is a clear winning option,
            D(i,1)=IX(i,a);                 %choose it 
        end
    else
        D(i,1)=0;
    end
    i=i+1;
end
                                        
                                        
v=D;            