function v=WAMH(Type,indicator,Contacts,Decisions,a)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns vector of agents decisions according to 'weighted        %
% additive model'; if there is no clear optimum WAM-decision, the  %
% old decision is maintained                                       %
% decisions of other agent types are set to zero                   %
%                                                                  %                                                                  %
% Input: type := vector of agent type with regard to used          %
% heuristic; indicator := labeling number of 'take the best' agent %
% type, Contacts := Matrix of contacts influence weights (cue      %
% values); Decisions := Vector of Decisions; a := number of        %
% alternatives                                                     %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), October 30th 2006    %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



n=length(Type(:,1));
D=Decisions;
IndivUWResult=zeros(n,a);                   %results of UW-counts for all agents

%--------Count Values of Propagating Neighbours over the 'a' alternatives-------

i=1;
j=1;
k=1;

for k=1:a
    i=1;
    for i=1:n
        j=1;
        for j=1:n
            if (Decisions(j,1)==k)&(Contacts(j,i)~=0)
                IndivUWResult(i,k)=IndivUWResult(i,k)+Contacts(j,i);
            end
            j=j+1;
        end
        i=i+1;
    end
    k=k+1;
end

%-----------Choose the alternative with maximum additive weight-------

%ContactIndex
%IndivUWResult

[SD,IX] = sort(IndivUWResult,2);            %Sort (ascending) Individual additive weight results over rows , 
                                            %return sorted matrix and indices

                                        
i=1;
for i=1:n
    if Type(i,1) == indicator               %if agent uses 'weighted additive model'
        if SD(i,a)==SD(i,a-1)               %if there is a tie regarding the (WAM-)best (a-th) option
            D(i,1)=Decisions(i,1);          %don't change decision 
        else                                %else, i.e. if there is a clear winning option,
            D(i,1)=IX(i,a);                 %choose it 
        end
    else
        D(i,1)=0;
    end
    i=i+1;
end
                                        
                                        
v=D;            