function v=conditionalMinimalistH(a,Type,indicator,Contacts,Decisions)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns vector of agents decisions according to 'minimalist'     %
% (i.e. random) heuristic, conditional on agent contacts           %
% decisions of other agent types are set to zero                   %
%                                                                  %
% Input: a := number of alternatives; type := vector of agent type %
% with regard to used heuristic; indicator := labeling number of   %
% 'minimalist' agent type; Contacts := Matrix of contacts influence %
% weights (cue values)Decisions := Vector of agents decisions      %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), October 30th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n=length(Type(:,1));
ContactIndex=zeros(n,n);               %0-1 contact indicator
nContacts=zeros(n,1);                  %counts contacts
rContacts=zeros(n,1);                  %random contact (order of contact)
backwards=n+1;                         %starting point for backwards-counting in index list
D=Decisions;

%---------------Build zero-one indicator matrix of contacts--------

%Contacts

i=1;
j=1;

for i=1:n
    for j=1:n
        if Contacts(i,j) ~= 0
            ContactIndex(i,j)=1;
        end
        j=j+1;
    end
    i=i+1;
end

%ContactIndex

%-----------------------Number of realized contacts---------------
i=1;
for i=1:n
    nContacts(i,1)=sum(ContactIndex(:,i));
    i=i+1;
end

%-----------------------Make Random Choice among Contacts---------

i=1;
for i=1:n
    rContacts(i,1)=ceil(rand(1)*nContacts(i,1));        %compute random choice (ordinal postion in list of contacts) 
    i=i+1;
end

[SW,IX] = sort(Contacts,1);                             %Sort (ascending) Contacts over columns (receiving node), 
                                                        %return sorted matrix and indices
%Contacts

i=1;

for i=1:n                                               %for all agents
    if Type(i,1) == indicator                           %if agent uses 'conditional minimalist'
        D(i,1)=Decisions(IX(backwards-rContacts(i,1),i),1);       %imitate decision of a randomly chosen contact (counting backwards in ascending ordered list) 
    else
        D(i,1)=0;                                       %Else set decision to zero (needed for combination of decisions of different agent types)
    end
    i=i+1;
end


%nContacts
%rContacts

v=D;

