function v=contactMinimalistTallied(ContactType,contactIndicator,Weights,Contacts,t)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns matrix of agents contact according to 'minimalist'       %
% heuristic; tallied by 't' contacts; Contacts -> selected         %
% incoming influences, selfweight is considered                    %
%                                                                  %
% Input: ContactTtype := vector of agent type with regard to used  %
% contact heuristic; contactIndicator := indicator vector for      %
% respective contact heuristic; Weights := Matrix of influence     %
% weights (cue values); Contacts := Matrix of realized contacts    %
% t := maximum number of contacts                                  %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), July 17th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n=length(Weights(1,:));                                     %N Agents
C=Contacts;                                            
C=zeros(n,n);
MaxCount=zeros(n,1);
ContactIndex=zeros(n,n);

%---------------Build zero-one indicator matrix of weights--------

i=1;
j=1;

for i=1:n
    for j=1:n
        if Weights(i,j) ~= 0
            WeightIndex(i,j)=1;
        end
        j=j+1;
    end
    i=i+1;
end

%-----------------Count number of neighbours-------------------------

i=1;

for i=1:n
    MaxCount(i,1)=sum(WeightIndex(:,i));
    i=i+1;
end


%-----------------Contact randomly-------------------------------

i=1;
j=1;

for i=1:n                                                      %for all agents 
    if ContactType(i,1) == contactIndicator                    %if agent is a 'minimalist'
        for j=1:t                                              %up to maximum information capacity
            if j<=MaxCount(i,1)                                %up to number of neighbours
                r=ceil(rand(1)*(n));                           %compute a random number between 1 and n
                while (Weights(r,i) == 0)|(C(r,i)~=0)          %which does not indicate a inbound zero link or an existing choice
                    r=ceil(rand(1)*(n));
                end
                rr=r;
                C(r,i)=Weights(r,i);                           %choose this inbound random link as contact
            end
            j=j+1;    
        end
        i=i+1;
    end
end  

%WeightIndex
%MaxCount

v=C;