function v=contactTakeProportional(ContactType,contactIndicator,Weights,Contacts)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns vector of agents contacts to 'weak Take The              %
% Best'-Heuristic: probability of imitation is proportional to level %
% of expertise/status                                              %
% decisions of other agent types are set to zero                   %
%                                                                  %
% Input: a := number of alternatives; type := vector of agent type %
% with regard to used heuristic; indicator := labeling number of   %
% 'takeProp' agent type; ontacts := Matrix of contacts influence   %
% weights (cue values)Decisions := Vector of agents decisions      %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), September 25th 2006  %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n=length(ContactType(:,1));
SumWeights=zeros(n,1);      %Sum of incoming Weights of Neighbours
RandomVector=zeros(n,1);    
LowerBound=zeros(n,1);      %initializations of weight dependant acceptance (~rejection) bounds
UpperBound=zeros(n,1);      %"" ""
C=Contacts;

%---------------Determine Sum of incoming Weights of Neighbours--------

%Type

i=1;

for i=1:n
    j=1;
    for j=1:n
        SumWeights(i,1) = SumWeights(i,1) + Weights(j,i);
        j=j+1;
    end
    i=i+1;
end

%SumWeights

%----------------build vector of random numbers between 0 and SumWeights(i,1)--------

i=1;

for i=1:n
    RandomVector(i,1)=rand(1)*SumWeights(i,1);
    i=i+1;
end

%---------------determine random contact----------------------

i=1;

for i=1:n                                                                                       %for all agents
    if ContactType(i,1) == contactIndicator                                                        %that are 'proportionalBest' (else: others remain zero as declared)
        
        j=1;
        for j=1:n                                                                                   %for all contacts
            if Weights(j,i)~=0                                                                     %that are realized
            
                UpperBound(i,1)=UpperBound(i,1)+Weights(j,i);                                      %Increment Upper bound by weight of contact
                if (RandomVector(i,1) > LowerBound(i,1)) & (RandomVector(i,1) < UpperBound(i,1))    %check wether random number is between bounds
                    C(j,i)=Weights(j,i);                                                          %if yes, make random contact
                    %break                                                                           %& proceed to next agent
                end
            
                LowerBound(i,1)=LowerBound(i,1)+Weights(j,i);                                      %increment lower bound by weight of contact                                                                                   
            end
            j=j+1;
        end
    end   
    i=i+1;
end

v=C;                                                                                            %return decisions

