function v=prefAtt(n, d)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% Returns adjacency matrix A of a preferential attachment network; %
% Input: n := number of vertices; d := minimum degree d >= 1;      %
%                                                                  %
% In addition to the original algorithm (see reference), also the  %
% upper diagonal of the adjacency matrix is instantiated, in order %
% to represent undirected relations. Furthermore the diagonal is   %
% set to 1, since the application explicitly assumes self loops.   %
%                                                                  %
% Reference: Algorithm 5 "preferential attachment" in              %
% "Batagelj, V., Brandes, U.: 2005, 'Efficient generation of large %
% random networks", PHYSICAL REVIEW E 71, 036113                   %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), June 12th 2006       %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M = zeros(2*n*d,1);
v = 0;
i = 0;

for v = 0:n-1
    v = v+1;                            %NOTE: INDEXES INCREMENTED
                                        %AT BEGINNING OF LOOP
    for i = 0:d-1
        i = i+1;                         
        
        M(2*(v*d+i),1) = v;
        r = ceil(rand(1)*(2*(v*d+i)));  %RAND. NUM. (0 TO 2*(v*d+i)) 
        M(2*(v*d+i)+1,1) = M(r,1);        
        
    end
end

A = zeros(n,n);
i = 0;

for i = 0:n*d-1
    i = i+1;
    
    if (M(2*i)~=0) & (M(2*i+1)~=0)      %CHECK IF NONZERO EDGE
        A(M(2*i),M(2*i+1)) = 1;         
        A(M(2*i+1),M(2*i)) = 1;         %SYMMETRICAL MATRIX
    end
end

%---------------------------------------%END OF ORIGINAL ALGORITHM

j = 0;
k = 0;

for j=0:n-1                            %LOOP SETS DIAGONAL TO 1
    j = j+1;
    for k=0:n-1
        k = k+1;
        
        if j == k                   
            A(j,k)=1;
        end     
    end
end

v=A;                                    %RETURN A