%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% repeats Experiments over Rule-Combinations sorted by Complexity  %
% REDUCED SET OF RULES
%                                                                  %
% COMPUTES AGGREGATED RESULTS OVER "plainRun"                      %
% which returns model trajectory matrix; uniform intial decisions; %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), December 06th 2006   %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
tic

%----DEFINE RUNS

%---- stable PARAMETERS
rep=1000;
nUpdates=50;
nAgents=21;
nAlternatives=3;
tallying=3;
contactUniform=1;
decisionUniform=1;

networkType=3;                                          %network type: 1-complete, 2-poisson, 3-scale free, 4-small world
connectionProbPoisson=0.4;
minDegreePref=4;
halfDimensionSmallWorld=2;
probRewireSmallWorld=1.0;

%ExList=[0.9;0.78;0.67;0.6;0.57;0.55;0.53;0.51;0.5];    %Condition: 9 Agents Shape JFlat
%ExList=[0.9;0.7;0.58;0.55;0.54;0.53;0.52;0.51;0.50];   %Condition: 9 Agents Shape JSteep
%ExList=[0.9;0.88;0.86;0.84;0.82;0.80;0.78;0.76;0.74];  %Contition: 9 Agents Shape Linear High
ExList=[0.7;0.68;0.66;0.64;0.62;0.60;0.58;0.56;0.54];  %Contition: 9 Agents Shape Linear Low

IniDecList=[1;1;1;2;2;2;3;3;3];                         %Condition: 9 Agents, uniform initial decision frequency distribution
%IniDecList=[1;1;1;1;2;2;2;3;3];                         %Condition: 9 Agents, flat initial decision frequency distribution
%IniDecList=[1;1;1;1;1;1;2;2;3];                         %Condition: 9 Agents, steep initial decision frequency distribution

%ExList=[0.9;0.84;0.78;0.72;0.67;0.63;0.6;0.585;0.57;0.56;0.55;0.54;0.53;0.52;0.51;0.5;0.49;0.485;0.482;0.481;0.48]; %JFlat 21
%ExList=[0.9;0.8;0.7;0.62;0.58;0.55;0.53;0.52;0.515;0.51;0.505;0.5;0.497;0.494;0.491;0.488;0.486;0.484;0.482;0.481;0.48]; %JSteep 21
%ExList=[0.9;0.892;0.884;0.876;0.868;0.86;0.852;0.844;0.836;0.828;0.82;0.812;0.804;0.796;0.788;0.78;0.772;0.764;0.756;0.748;0.74]; %LinHigh 21
%ExList=[0.7;0.692;0.684;0.676;0.668;0.66;0.652;0.644;0.636;0.628;0.62;0.612;0.604;0.596;0.588;0.58;0.572;0.564;0.556;0.548;0.54]; %LinLow 21

%IniDecList=[1;1;1;1;1;1;1;2;2;2;2;2;2;2;3;3;3;3;3;3;3]; % 21 Agents / Uniform


%ExList=[0.9;0.82;0.77;0.72;0.69;0.67;0.65;0.62;0.61;0.6;0.59;0.58;0.57;0.56;0.55;0.545;0.54;0.535;0.53;0.525;0.52;0.515;0.51;0.505;0.5;0.497;0.494;0.491;0.488;0.485;0.482]; %JFlat 31
%ExList=[0.9;0.8;0.72;0.64;0.6;0.56;0.52;0.51;0.5;0.495;0.49;0.488;0.486;0.484;0.483;0.482;0.481;0.481;0.48;0.48;0.479;0.479;0.478;0.478;0.477;0.477;0.476;0.475;0.475;0.474;0.474]; %JSteep 31
%ExList=[0.9;0.894;0.888;0.882;0.876;0.87;0.864;0.858;0.852;0.846;0.84;0.834;0.828;0.822;0.816;0.81;0.804;0.798;0.792;0.786;0.78;0.774;0.768;0.762;0.756;0.75;0.744;0.738;0.732;0.726;0.72]; %LinHigh 31
%ExList=[0.7;0.694;0.688;0.682;0.676;0.67;0.664;0.658;0.652;0.646;0.64;0.634;0.628;0.622;0.616;0.61;0.604;0.598;0.592;0.586;0.58;0.574;0.568;0.562;0.556;0.55;0.544;0.538;0.532;0.526;0.52]; %LinLow 31

%IniDecList=[1;1;1;1;1;1;1;1;1;1;
%            2;2;2;2;2;2;2;2;2;2;
%            3;3;3;3;3;3;3;3;3;3;3]; %31 Agents / Uniform

runs=6;
%resultsMatrix=zeros(17,17);                                 %17 runs 17 statistics collected
resultsMatrix=zeros(runs,1);

for idrun=1:runs                                            %---RUNS-LOOP

%---- dynamic PARAMETERS

    %ContactTypes: 1-minimalistTallied, 2-all, 3-TTB, 4-BE, 5-take proportional
    %DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM, 5-take proportional

    if idrun==1                     %sorted by complexity
        contactType=2;              %ContactTypes: 1-minimalistTallied, 2-all, 3-TTB, 4-BE, 5-take proportional
        decisionType=1;             %DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM, 5-take proportional
    elseif idrun==2
        contactType=4;
        decisionType=1;
    elseif idrun==3
        contactType=2;
        decisionType=2;
    elseif idrun==4
        contactType=4;
        decisionType=3;
    elseif idrun==5
        contactType=2;
        decisionType=3;
    elseif idrun==6
        contactType=2;
        decisionType=4;
    end
            
    %----auxiliary parameters

    global Weights;                                  %declaration "global" in main- and subfunctions makes "Weights" globally availiable;
                                                     %necessary for determination of expertize

    all=0;                                           %parameters of proportionOpinionChange
    experts=1;

    allExperts=0;                                    %parameters of determineCompromiseQuality
    bestExpert=1;

    %----INSTRUCTIONS

    UnanimityCycleVector=zeros(1,rep);               %vector of n(cycle) in which unanimity is reached
    unAnimityVector=zeros(1,rep);                    %vector indicators (1/0) wether 1animity is reached        
    twoAnimityVector=zeros(1,rep);                   %vector indicators (1/0) wether 2animity is reached
    threeAnimityVector=zeros(1,rep);                 %vector indicators (1/0) wether 3animity is reached
    proportionChangesVector=zeros(1,rep);            %vector of proportions of decision changes (all)
    proportionExpertChangesVector=zeros(1,rep);      %vector of proportions of decision changes (experts)
    CompromiseQualityVector=zeros(1,rep);            %vector of indicators (1/2, 0) wether unianimous decison differs from expert initial decision
    CompromiseQualityVectorAllExperts=zeros(1,rep);  %vector of indicators (1/2, 0) wether unianimous decison differs from experts mode initial decision
    EquilibriumCycleVector=zeros(1,rep);             %vector of equilibrium cycles for each run
    finalDistributionsMatrix=zeros(nAlternatives,rep);     %matrix of final frequencies of alternatives for each repetition
    
    k=1;
    for k=1:rep                         %REPEAT SIMULATIONS AND COMPUTE AGGREGATE RESULTS

        %----compute trajectory

        Trajectory=plainRun(nUpdates,nAgents,nAlternatives,tallying,contactUniform,decisionUniform,networkType,connectionProbPoisson,minDegreePref,halfDimensionSmallWorld,probRewireSmallWorld,contactType,decisionType,ExList,IniDecList);                  

        %Trajectory

        %----collect some data

        UnanimityCycleVector(1,k)=cycleUnanimity(Trajectory);                   %count cycle in which unanimity is reached

        unAnimityVector(1,k)=determineUnAnimity(UnanimityCycleVector(1,k));     %build indicator vector of 1-animity
        twoAnimityVector(1,k)=determineTwoAnimity(Trajectory);                  %build indicator vector of 2-animity    
        threeAnimityVector(1,k)=determineThreeAnimity(Trajectory);              %build indicator vector of 3-animity

        proportionChangesVector(1,k)=proportionOpinionChange(Trajectory,Weights,all);   %build vector of decision change proportions
        proportionExpertChangesVector(1,k)=proportionOpinionChange(Trajectory,Weights,experts); % "" for experts

        CompromiseQualityVector(1,k)=determineCompromiseQuality(Trajectory,Weights,UnanimityCycleVector(1,k),bestExpert);            %build vector of group decision quality (does best expert change decision?)
        CompromiseQualityVectorAllExperts(1,k)=determineCompromiseQuality(Trajectory,Weights,UnanimityCycleVector(1,k),allExperts);  %build vector of group decision quality (is group decision the mode expert decision?) 

        EquilibriumCycleVector(1,k)=equilibriumCycle(Trajectory);               %store equilibrium cycle for each run
        
        finalDistributionsMatrix(:,k)=finalDistributions(Trajectory,nAlternatives,nUpdates);
        %----increment loop

        k=k+1;

    end                                 %END REPEAT SIMULATIONS

    %rep                                 %output n repetitions
    %time=toc                            %output time


                                        %CLEAN VECTORS FROM NON-UNANIMITY

    %UnanimityCycleVector
    ClUnanimityCycleVector=cleanUnAnimityCycleVector(UnanimityCycleVector);                             %clean cycle-vector from zeros (repetitions without unanimity)
    ClCompromiseQualityVector=cleanUnAnimityCycleVector(CompromiseQualityVector);                       %clean quality-vector from zeros (repetitions without unanimity)
    ClCompromiseQualityVectorAllExperts=cleanUnAnimityCycleVector(CompromiseQualityVectorAllExperts);   %clean quality-vector from zeros (repetitions without unanimity)

                                        %ANALYZE DATA


    pUni=proportionKAnimity(unAnimityVector);                                   %buid distribution of k-animity
    pTwo=proportionKAnimity(twoAnimityVector);
    pTri=proportionKAnimity(threeAnimityVector);

    KAnimityDistribution = [pUni pTwo pTri];

    meanAggrementCycle=mean(ClUnanimityCycleVector);                             %determine mean unanimity cycle
    stdDevAggrementCycle=std(ClUnanimityCycleVector);

    meanPropChange=mean(proportionChangesVector);                                %determine mean change rate of agents (experts)
    stdDevPropChange=std(proportionChangesVector);

    meanPropExpChange=mean(proportionExpertChangesVector);
    stdDevPropExpChange=std(proportionExpertChangesVector);

    pBestExpertQuality=proportionQualityDecisions(ClCompromiseQualityVector);   %determine qualitiy of group decision, if unanimous

    pAllExpertQuality=proportionQualityDecisions(ClCompromiseQualityVectorAllExperts);

    meanEquilibriumCycle=mean(EquilibriumCycleVector(1,:));                     %determine mean Equilibrium Cycle over runs
    
    meanFinalDistrib1=mean(finalDistributionsMatrix(1,:));                       %determine mean final decision ddistribution of runs
    meanFinalDistrib2=mean(finalDistributionsMatrix(2,:));
    meanFinalDistrib3=mean(finalDistributionsMatrix(3,:));

    stdFinalDistrib1=std(finalDistributionsMatrix(1,:));                         %determine std.dev. of means
    stdFinalDistrib2=std(finalDistributionsMatrix(2,:));
    stdFinalDistrib3=std(finalDistributionsMatrix(3,:));

    
    JointResults=meanEquilibriumCycle;                                          %store only meanEqulibriumCycles
    %JointResults=[pUni, pTwo, pTri, meanAggrementCycle, stdDevAggrementCycle, meanPropChange, stdDevPropChange, meanPropExpChange, stdDevPropExpChange, pBestExpertQuality, pAllExpertQuality, meanFinalDistrib1, meanFinalDistrib2, meanFinalDistrib3, stdFinalDistrib1, stdFinalDistrib3, stdFinalDistrib3];
        
                                    %SAVE RESULTS;
                                    
    resultsMatrix(idrun,:)=JointResults                                        %remember joint results of single run
    
    duration=toc                                                                %output time up to point
    
    idrun=idrun+1                                                               %increment counter of experiments (next configuration)

end                                 %---end of RUNS-loop
                                    
    
                                    
save qRunVarReduxEqui resultsMatrix;                     %Save resultsMatrix (*.mat, *.dat)
dlmwrite('qRunVarReduxEqui.csv', resultsMatrix, ',');

 
