%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
% COMPUTES AGGREGATED RESULTS OVER "plainRun"                      %
% which returns model trajectory matrix; uniform intial decisions; %
%                                                                  %
% Author: Gero Schwenk (Gero.Schwenk@web.de), August 29th 2006     %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
tic

%----REPETITIONS
rep=1;

%----PARAMETERS
nUpdates=50;
nAgents=9;
nAlternatives=3;
tallying=3;
contactUniform=1;
decisionUniform=1;
networkType=1;                                          %network type: 1-complete, 2-poisson, 3-scale free, 4-small world
connectionProbPoisson=0.4;
minDegreePref=4;
halfDimensionSmallWorld=1;
probRewireSmallWorld=0.3;
contactType=2;                                          %ContactTypes: 1-minimalistTallied, 2-all, 3-TTB, 4-BE, 5-take proportional
decisionType=2;                                        %DecisionTypes: 1-conditionalMinimalist, 2-TTB, 3-UWM, 4-WAM, 5-take proportional

%ExList=[0.9;0.78;0.67;0.6;0.57;0.55;0.53;0.51;0.5];    %Condition: 9 Agents Shape JFlat
%ExList=[0.9;0.7;0.58;0.55;0.54;0.53;0.52;0.51;0.50];   %Condition: 9 Agents Shape JSteep
%ExList=[0.9;0.88;0.86;0.84;0.82;0.80;0.78;0.76;0.74];  %Contition: 9 Agents Shape Linear High
ExList=[0.7;0.68;0.66;0.64;0.62;0.60;0.58;0.56;0.54];  %Contition: 9 Agents Shape Linear Low

IniDecList=[1;1;1;2;2;2;3;3;3];                         %Condition: 9 Agents, uniform initial decision frequency distribution
%IniDecList=[1;1;1;1;2;2;2;3;3];                         %Condition: 9 Agents, flat initial decision frequency distribution
%IniDecList=[1;1;1;1;1;1;2;2;3];                         %Condition: 9 Agents, steep initial decision frequency distribution

%----auxiliary parameters

global Weights;                                  %declaration "global" in main- and subfunctions makes "Weights" globally availiable;
                                                 %necessary for determination of expertize
                                        
all=0;                                           %parameters of proportionOpinionChange
experts=1;

allExperts=0;                                    %parameters of determineCompromiseQuality
bestExpert=1;

%----INSTRUCTIONS

UnanimityCycleVector=zeros(1,rep);               %vector of n(cycle) in which unanimity is reached
unAnimityVector=zeros(1,rep);                    %vector indicators (1/0) wether 1animity is reached        
twoAnimityVector=zeros(1,rep);                   %vector indicators (1/0) wether 2animity is reached
threeAnimityVector=zeros(1,rep);                 %vector indicators (1/0) wether 3animity is reached
proportionChangesVector=zeros(1,rep);            %vector of proportions of decision changes (all)
proportionExpertChangesVector=zeros(1,rep);      %vector of proportions of decision changes (experts)
CompromiseQualityVector=zeros(1,rep);            %vector of indicators (1/2, 0) wether unianimous decison differs from expert initial decision
CompromiseQualityVectorAllExperts=zeros(1,rep);  %vector of indicators (1/2, 0) wether unianimous decison differs from experts mode initial decision
finalDistributionsMatrix=zeros(nAlternatives,rep);     %matrix of final frequencies of alternatives for each repetition


k=1;
for k=1:rep                         %REPEAT SIMULATIONS AND COMPUTE AGGREGATE RESULTS
     
    %----compute trajectory
    
    Trajectory=plainRun(nUpdates,nAgents,nAlternatives,tallying,contactUniform,decisionUniform,networkType,connectionProbPoisson,minDegreePref,halfDimensionSmallWorld,probRewireSmallWorld,contactType,decisionType,ExList,IniDecList);                  
    
    %Trajectory
    
    %----collect some data
    
    UnanimityCycleVector(1,k)=cycleUnanimity(Trajectory);                   %count cycle in which unanimity is reached
    
    unAnimityVector(1,k)=determineUnAnimity(UnanimityCycleVector(1,k));     %build indicator vector of 1-animity
    twoAnimityVector(1,k)=determineTwoAnimity(Trajectory);                  %build indicator vector of 2-animity    
    threeAnimityVector(1,k)=determineThreeAnimity(Trajectory);              %build indicator vector of 3-animity
    
    proportionChangesVector(1,k)=proportionOpinionChange(Trajectory,Weights,all);   %build vector of decision change proportions
    proportionExpertChangesVector(1,k)=proportionOpinionChange(Trajectory,Weights,experts); % "" for experts
    
    CompromiseQualityVector(1,k)=determineCompromiseQuality(Trajectory,Weights,UnanimityCycleVector(1,k),bestExpert);            %build vector of group decision quality (does best expert change decision?)
    CompromiseQualityVectorAllExperts(1,k)=determineCompromiseQuality(Trajectory,Weights,UnanimityCycleVector(1,k),allExperts);  %build vector of group decision quality (is group decision the mode expert decision?) 
    
    
    finalDistributionsMatrix(:,k)=finalDistributions(Trajectory,nAlternatives,nUpdates);
    %----increment loop
    
    k=k+1;
    
end                                 %END REPEAT SIMULATIONS

rep                                 %output n repetitions
time=toc                            %output time
   
    
                                    %CLEAN VECTORS FROM NON-UNANIMITY
    
%UnanimityCycleVector
ClUnanimityCycleVector=cleanUnAnimityCycleVector(UnanimityCycleVector);                             %clean cycle-vector from zeros (repetitions without unanimity)
ClCompromiseQualityVector=cleanUnAnimityCycleVector(CompromiseQualityVector);                       %clean quality-vector from zeros (repetitions without unanimity)
ClCompromiseQualityVectorAllExperts=cleanUnAnimityCycleVector(CompromiseQualityVectorAllExperts);   %clean quality-vector from zeros (repetitions without unanimity)

                                    %ANALYZE DATA
        

pUni=proportionKAnimity(unAnimityVector);                                   %buid distribution of k-animity
pTwo=proportionKAnimity(twoAnimityVector);
pTri=proportionKAnimity(threeAnimityVector);

KAnimityDistribution = [pUni pTwo pTri]

meanAggrementCycle=mean(ClUnanimityCycleVector)                             %determine mean unanimity cycle
stdDevAggrementCycle=std(ClUnanimityCycleVector)

meanPropChange=mean(proportionChangesVector)                                %determine mean change rate of agents (experts)
stdDevPropChange=std(proportionChangesVector)

meanPropExpChange=mean(proportionExpertChangesVector)
stdDevPropExpChange=std(proportionExpertChangesVector)

pBestExpertQuality=proportionQualityDecisions(ClCompromiseQualityVector)   %determine qualitiy of group decision, if unanimous

pAllExpertQuality=proportionQualityDecisions(ClCompromiseQualityVectorAllExperts)

meanFinalDistrib1=mean(finalDistributionsMatrix(1,:))                       %determine mean final decision ddistribution of runs
meanFinalDistrib2=mean(finalDistributionsMatrix(2,:))
meanFinalDistrib3=mean(finalDistributionsMatrix(3,:))

stdFinalDistrib1=std(finalDistributionsMatrix(1,:))                         %determine std.dev. oof means
stdFinalDistrib2=std(finalDistributionsMatrix(2,:))
stdFinalDistrib3=std(finalDistributionsMatrix(3,:))

JointResults=[pUni, pTwo, pTri, meanAggrementCycle, stdDevAggrementCycle, meanPropChange, stdDevPropChange, meanPropExpChange, stdDevPropExpChange, pBestExpertQuality, pAllExpertQuality, meanFinalDistrib1, meanFinalDistrib2, meanFinalDistrib3, stdFinalDistrib1, stdFinalDistrib3, stdFinalDistrib3];

                                    %SAVE RESULTS;
                                    
save Exp1 JointResults;                     %SaveJoint Results (*.mat, *.dat)
dlmwrite('Exp1.csv', JointResults, ',');

time
    
